# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`vim`](#vim): Installs and configures the vim package.
* [`vim::configure`](#vimconfigure): Global vim configuration. Realizes all virtual user configs and sets up resource order. It is not recommended to include this directly.
* [`vim::install`](#viminstall): Installs the vim package. It is not recommended to use this class directly.

**Defined types**

* [`vim::bundle`](#vimbundle): Install Pathogen/vim plugin bundles.
* [`vim::config`](#vimconfig): Manage a user's vim configuration.
* [`vim::plugin`](#vimplugin): Install a vim pugin.

## Classes

### vim

Installs and configures the vim package.

#### Examples

##### 

```puppet
include vim
```

### vim::configure

Global vim configuration. Realizes all virtual user configs and sets up resource order. It is not recommended to include this directly.

#### Examples

##### 

```puppet
include vim::configure
```

### vim::install

Installs the vim package. It is not recommended to use this class directly.

#### Examples

##### 

```puppet
include vim::install
```

#### Parameters

The following parameters are available in the `vim::install` class.

##### `package_ensure`

Data type: `String`

Ensure to pass to the package resource.

##### `package_name`

Data type: `String`

Vim package name for the package resource.

## Defined types

### vim::bundle

Install Pathogen/vim plugin bundles.

#### Examples

##### Install Puppet bundle from GitHub

```puppet
vim::bundle { 'puppet':
  ensure   => present,
  owner    => 'brwyatt',
  repo     => 'https://github.com/voxpupuli/vim-puppet.git',
  revision => 'master',
  vim_dir  => '/home/brwyatt/.vim',
}
```

#### Parameters

The following parameters are available in the `vim::bundle` defined type.

##### `owner`

Data type: `String`

The username of the owner of this bundle's files.

##### `repo`

Data type: `String`

URL/Path to the repo source for the bundle.

##### `vim_dir`

Data type: `String`

Path to the user's `.vim` directory containing the `bundles` directory.

##### `bundle_name`

Data type: `String`

The bundle's name.

Default value: $name

##### `ensure`

Data type: `Enum['present', 'absent']`

Resource ensure value.

Default value: 'present'

##### `group`

Data type: `String`

Group name for bundle's permissions.

Default value: $owner

##### `provider`

Data type: `String`

The provider value to pass to `vcsrepo`. Can be any valid provider accepted by `vcsrepo`.

Default value: 'git'

##### `revision`

Data type: `String`

Repository revision to checkout.

Default value: 'master'

### vim::config

Manage a user's vim configuration.

#### Examples

##### 

```puppet
vim::config { '/home/brwyatt':
  ensure => present,
  owner  => 'brwyatt',
}
```

#### Parameters

The following parameters are available in the `vim::config` defined type.

##### `owner`

Data type: `String`

Username of the owner of the configs.

##### `vimrc_template`

Data type: `String`

Template file/path used to generate the user's `.vimrc`.

Default value: 'vim/pathogen_vimrc.epp'

##### `vimrc_params`

Data type: `Hash`

Template params to pass to the template indicated by `$vimrc_template`.

Default value: {}

##### `ensure`

Data type: `Enum['present', 'absent']`

Resource ensure.

Default value: 'present'

##### `group`

Data type: `String`

Name of the group that owns the configs.

Default value: $owner

##### `path`

Data type: `String`

The path to the directory containing the configs. This should be the parent directory that the `.vimrc` and `.vim` directory should be created.

Default value: $name

### vim::plugin

Install a vim pugin.

#### Examples

##### 

```puppet
vim::plugin { 'pathogen':
  owner    => 'brwyatt',
  autoload => true,
  source   =>
    'https://raw.githubusercontent.com/tpope/vim-pathogen/v2.4/autoload/pathogen.vim',
  vim_dir  => '/home/brwyatt/.vim',
}
```

#### Parameters

The following parameters are available in the `vim::plugin` defined type.

##### `owner`

Data type: `String`

The username of the owner of this plugin.

##### `vim_dir`

Data type: `String`

Path to the user's `.vim` directory containing the `plugin` and `autoload` directories.

##### `autoload`

Data type: `Boolean`

Controls if this plugin should be symlinked from the `autoload` directory.

Default value: `false`

##### `plugin_name`

Data type: `String`

The plugin's name. `.vim` will be appended to this name if not included.

Default value: $name

##### `ensure`

Data type: `Enum['present', 'absent']`

Resource ensure value.

Default value: 'present'

##### `group`

Data type: `String`

Group name for plugin's permissions.

Default value: $owner

##### `content`

Data type: `Optional[String]`

Content of the plugin file. Mutually exclusive with `$source`.

Default value: `undef`

##### `source`

Data type: `Optional[String]`

Source location of the plugin file. Mutually exclusive with `$content`.
Note: if source is an http/https URL, `$content` is ignored completely without error.

Default value: `undef`

